summaryrefslogtreecommitdiff
path: root/include/basegfx/color
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2015-02-16 20:43:04 +0000
committerCaolán McNamara <caolanm@redhat.com>2015-02-16 22:59:52 +0000
commit0ae82ba5d2b0ab81cac27efbb0226ed0f15d3b96 (patch)
tree21babdf653b2ba50c97ea5a22250636b19d9f6a1 /include/basegfx/color
parent8d997133c3f10d3f57e9670e2bc2e1b6471ac112 (diff)
cut down some more unnecessary boost inclusion
Change-Id: Ia997e243d28a54d2e3cc9714fe3e7e86d198797c
Diffstat (limited to 'include/basegfx/color')
-rw-r--r--include/basegfx/color/bcolormodifier.hxx15
1 files changed, 7 insertions, 8 deletions
diff --git a/include/basegfx/color/bcolormodifier.hxx b/include/basegfx/color/bcolormodifier.hxx
index 33287cee05dd..b6278e045e9d 100644
--- a/include/basegfx/color/bcolormodifier.hxx
+++ b/include/basegfx/color/bcolormodifier.hxx
@@ -25,12 +25,9 @@
#include <osl/diagnose.h>
-#include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
+#include <memory>
#include <vector>
-
-
namespace basegfx
{
/** base class to define color modifications
@@ -55,13 +52,15 @@ namespace basegfx
operator); local values cannot be changed after construction. The
instances are cheap and the idea is to create them on demand. To
be able to reuse these as much as possible, a define for a
- ::boost::shared_ptr named BColorModifierSharedPtr exists below.
+ std::shared_ptr named BColorModifierSharedPtr exists below.
All usages should handle instances of BColorModifier encapsulated
into these shared pointers.
*/
- class BASEGFX_DLLPUBLIC SAL_WARN_UNUSED BColorModifier : private boost::noncopyable
+ class BASEGFX_DLLPUBLIC SAL_WARN_UNUSED BColorModifier
{
private:
+ BColorModifier(const BColorModifier&) SAL_DELETED_FUNCTION;
+ BColorModifier& operator=(const BColorModifier&) SAL_DELETED_FUNCTION;
protected:
// no one is allowed to incarnate the abstract base class
// except derivations
@@ -69,7 +68,7 @@ namespace basegfx
public:
// no one should directly destroy it; all incarnations should be
// handled in a boost::shared_ptr of type BColorModifierSharedPtr
virtual ~BColorModifier();
// compare operator
@@ -374,7 +373,7 @@ namespace basegfx
{
/// typedef to allow working with shared instances of BColorModifier
/// for the whole mechanism
- typedef ::boost::shared_ptr< BColorModifier > BColorModifierSharedPtr;
+ typedef std::shared_ptr< BColorModifier > BColorModifierSharedPtr;
/** Class to hold a stack of BColorModifierSharedPtrs and to get the modified color with
applying all existing entry changes as defined in the stack. Instances of BColorModifier
@@ -69,7 +68,7 @@ namespace basegfx
public:
// no one should directly destroy it; all incarnations should be
- // handled in a boost::shared_ptr of type BColorModifierSharedPtr
+ // handled in a std::shared_ptr of type BColorModifierSharedPtr
virtual ~BColorModifier();
// compare operator